@@ -42,35 +42,27 @@
 
 class Mod3 : public DealerScene
 {
-    friend class Mod3Solver;
-
     Q_OBJECT
 
 public:
-    Mod3( );
-
-    void deal();
-
-    virtual void restart();
-
-public slots:
-    virtual Card *newCards();
+    virtual void initialize();
+    virtual void moveCardsToPile( QList<KCard*> cards, KCardPile * pile, int duration );
 
 protected:
     virtual void setGameState(const QString & );
+    virtual bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const;
+    virtual bool checkRemove(const PatPile * pile, const QList<KCard*> & cards) const;
+    virtual void restart();
 
-private: // functions
-    virtual bool checkAdd( int checkIndex, const Pile *c1, const CardList& c2) const;
-    virtual bool checkPrefering( int checkIndex, const Pile *c1, const CardList& c2) const;
-
-    void         dealRow(int row);
+protected slots:
+    virtual bool newCards();
 
 private:
-    Pile  *talon;
-    Pile  *stack[4][8];
-    Pile  *aces;
+    PatPile  *talon;
+    PatPile  *stack[4][8];
+    PatPile  *aces;
+
+    friend class Mod3Solver;
 };
 
 #endif
-
-//-------------------------------------------------------------------------//
